<template>
  <div>
    <viewer :images="images">
      <img
        v-for="(src,index) in images"
        :key="index"
        class="v-img"
        :src="src.url"
        :alt="src.name"
        :style="imgStyle"
        :onerror="defaultImg"
      >
    </viewer>
  </div>
</template>

<script>
import { getFtpUrl } from '@/utils/base'
import { str2Array } from '@/utils/tools'
export default {
  props: {
    imgs: {
      type: [Array, String],
      default: function() {
        return []
      }
    },
    imgStyle: {
      type: String,
      default: 'width:100px; height:100px;'
    }
  },
  data() {
    return {
      defaultImg: 'this.src="' + require('../../../assets/404_images/404.png') + '"',
      images: []
    }
  },
  watch: {
    imgs(val) {
      if (typeof val === 'string') {
        this.images = str2Array(val)
      } else {
        this.images = val
      }
    }
  },
  created() {
    if (typeof this.imgs === 'string') {
      this.images = str2Array(this.imgs)
    } else {
      this.images = this.imgs
    }
  },
  mounted() {
    this.images.forEach(obj => {
      if (obj.path != undefined && obj.path.length > 0) {
        obj.url = this.getUrl(obj.path)
      }
    })
  },
  methods: {
    getUrl(path) {
      return getFtpUrl() + path
    }
  }
}
</script>

<style scoped>
  /* 图片预览层级*/
  .viewer-container {
    z-index: 90709102!important;
  }
</style>
